package com.example.juanalonsoastruga.cargascontrol.Formateador.CUConsultarEstadisticaCombustible;

import com.example.juanalonsoastruga.cargascontrol.CapaTransversal.DTODatosDerivadosCombustible;
import com.example.juanalonsoastruga.cargascontrol.Controlador.CUConsultarEstadisticaCombustible.InterfaceCConsultarEstadisticaCombustible;
import com.example.juanalonsoastruga.cargascontrol.Controlador.CUConsultarEstadisticaCombustible.ControladorConsultarEstadisticaCombustible;

import java.math.RoundingMode;
import java.text.DecimalFormat;

/**
 * Clase FormateadorConsultarEstadisticaCombustible, representa el formateador en el CU Consultar Estadisticas de uso de Combustible.
 *
 */
public class FormateadorConsultarEstadisticaCombustible implements InterfaceFConsultarEstadisticaCombustible, InterfaceFConsultarEstadisticaCombustibleImpl {

    private InterfaceCConsultarEstadisticaCombustible controlador;

    private DTODatosDerivadosCombustible datos;

    /**
     * Constructor de clase.
     *
     */
    public FormateadorConsultarEstadisticaCombustible(){
        setControlador(new ControladorConsultarEstadisticaCombustible(this));
    }

    /**
     * Metodo setControlador, establece el controlador relacionado al formateador.
     *
     * @param controlador Objeto InterfaceCConsultarEstadisticaCombustible
     * @throws IllegalArgumentException si el argumento es null
     */
    @Override
    public void setControlador(InterfaceCConsultarEstadisticaCombustible controlador){
        if(controlador==null){
            throw new IllegalArgumentException();
        }else{
            this.controlador =controlador;
        }
    }

    /**
     * Metodo getControlador, devuelve el controlador asociado.
     *
     * @return InterfaceCConsultarEstadisticaCombustible
     */
    @Override
    public InterfaceCConsultarEstadisticaCombustible getControlador() {
        return this.controlador;
    }

    /**
     * Metodo comienzaCU, da comienzo al caso de uso avisando al controlador para ello.
     *
     * @param matricula String con la matricula del vehiculo sobre el que se consulta
     * @param id int con el id del combustible primario o secundario a consultar
     */
    @Override
    public void comienzaCU(String matricula, int id) {
        controlador.comienzoCU(matricula,id);
    }

    /**
     * Metodo getMatricula, devuelve la matricula asociada al vehiculo consultado.
     *
     * @throws IllegalStateException si no se han asignado datos derivados anteriormente
     * @return String con la matricula
     */
    @Override
    public String getMatricula() {
        if(datos==null){
            throw new IllegalStateException();
        }else {
            return datos.getMatriculaVehiculo();
        }
    }

    /**
     * Metodo getMes, devuelve el numero de mes de la ultima recarga de la que se extrayeron datos derivados.
     *
     * @throws IllegalStateException si no se han asignado datos derivados anteriormente
     * @return  int con el numero de mes (1 a 12)
     */
    @Override
    public int getMes() {
        if(datos==null){
            throw new IllegalStateException();
        }else { return (datos.getMes() + 1) ;}
    }

    /**
     * Metodo getAnio, devuelve el anio de la ultima recarga de la que se extrayeron datos derivados.
     *
     * @throws IllegalStateException si no se han asignado datos derivados anteriormente
     * @return  int con el numero de anio
     */
    @Override
    public int getAnio() {
        if(datos==null){
            throw new IllegalStateException();
        }else {
            return datos.getAnio();}
    }

    /**
     * Metodo getNumerosRecargasMes, devuelve el numero de recargas del ultimo mes .
     *
     * @throws IllegalStateException si no se han asignado datos derivados anteriormente
     * @return int con el numero
     */
    @Override
    public int getNumerosRecargasMes() {
        if(datos==null){
            throw new IllegalStateException();
        }else {
            return datos.getNumeroRecargasCombustiblePorMes();
        }
    }

    /**
     * Metodo getNumerosRecargasAnio, devuelve el numero de recargas del ultimo anio.
     *
     * @throws IllegalStateException si no se han asignado datos derivados anteriormente
     * @return int con el numero
     */
    @Override
    public int getNumerosRecargasAnio() {
        if(datos==null){
            throw new IllegalStateException();
        }else {
            return datos.getNumeroRecargasCombustiblePorAnio();
        }
    }

    /**
     * Metodo getMedicionCombustibleMes, devuelve la medicion de combustible recargado en el ultimo mes.
     *
     * @throws IllegalStateException si no se han asignado datos derivados anteriormente
     * @return  String con la cantidad formateada
     */
    @Override
    public String getMedicionCombustibleMes() {
        if(datos==null){
            throw new IllegalStateException();
        }else {
            DecimalFormat formato = new DecimalFormat("#.##");
            formato.setRoundingMode(RoundingMode.CEILING);
            double valor=  datos.getSumaCombustibleRecargadoPorMes();
            return formato.format(valor).replace('.',',');
        }
    }

    /**
     * Metodo getMediaMedicionCombustibleMes, devuelve la media de las mediciones de recargas del
     * combustible en el ultimo mes.
     *
     * @throws IllegalStateException si no se han asignado datos derivados anteriormente
     * @return String formateado con la cantidad
     */
    @Override
    public String getMediaMedicionCombustibleMes() {
        if(datos==null){
            throw new IllegalStateException();
        }else {
            double valor = datos.getMediaCombustibleMensualRecargado();
            DecimalFormat formato = new DecimalFormat("#.##");
            formato.setRoundingMode(RoundingMode.CEILING);
            return formato.format(valor).replace('.',',');
        }
    }

    /**
     * Metodo getMedicionCombustibleAnio, devuelve la medicion de combustible recargado en el ultimo anio.
     *
     * @throws IllegalStateException si no se han asignado datos derivados anteriormente
     * @return  String con la cantidad formateada
     */
    @Override
    public String getMedicionCombustibleAnio() {
        if(datos==null){
            throw new IllegalStateException();
        }else {
            DecimalFormat formato = new DecimalFormat("#.##");
            formato.setRoundingMode(RoundingMode.CEILING);
            double valor= datos.getSumaCombustibleRecargadoPorAnio();
            return formato.format(valor).replace('.',',');
        }
    }

    /**
     * Metodo getMediaMedicionCombustibleAnio, devuelve la media de mediciones de combustible recargado en el ultimo anio.
     *
     * @throws IllegalStateException si no se han asignado datos derivados anteriormente
     * @return String con la cantidad formateada
     */
    @Override
    public String getMediaMedicionCombustibleAnio() {
        if(datos==null){
            throw new IllegalStateException();
        }else {
            double valor = datos.getMediaCombustibleAnualRecargado();
            DecimalFormat formato = new DecimalFormat("#.##");
            formato.setRoundingMode(RoundingMode.CEILING);
            return formato.format(valor).replace('.',',');
        }
    }

    /**
     * Metodo getMinimoCombustibleMes, devuelve el minimo de combustible recargado en el ultimo mes.
     *
     * @throws IllegalStateException si no se han asignado datos derivados anteriormente
     * @return String con  la cantidad formateada
     */
    @Override
    public String getMinimoCombustibleMes() {
        if(datos==null){
            throw new IllegalStateException();
        }else {
            DecimalFormat formato = new DecimalFormat("#.##");
            formato.setRoundingMode(RoundingMode.CEILING);
            double valor=datos.getMinimoCombustibleMensualRecargado();
            return formato.format(valor).replace('.',',');
        }
    }

    /**
     * Metodo getMaximoCombustibleMes,  devuelve el maximo de combustible recargado en el ultimo mes.
     *
     * @throws IllegalStateException si no se han asignado datos derivados anteriormente
     * @return String con  la cantidad formateada
     */
    @Override
    public String getMaximoCombustibleMes() {
        if(datos==null){
            throw new IllegalStateException();
        }else {
            DecimalFormat formato = new DecimalFormat("#.##");
            formato.setRoundingMode(RoundingMode.CEILING);
            double valor=datos.getMaximoCombustibleMensualRecargado();
            return formato.format(valor).replace('.',',');
        }
    }

    /**
     * Metodo getMinimoCombustibleAnio, devuelve el minimo combustible recargado en el ultimo anio.
     *
     * @throws IllegalStateException si no se han asignado datos derivados anteriormente
     * @return String con  la cantidad formateada
     */
    @Override
    public String getMinimoCombustibleAnio() {
        if(datos==null){
            throw new IllegalStateException();
        }else {
            DecimalFormat formato = new DecimalFormat("#.##");
            formato.setRoundingMode(RoundingMode.CEILING);
            double valor=datos.getMinimoCombustibleAnualRecargado();
            return formato.format(valor).replace('.',',');
        }
    }


    /**
     * Metodo getMaximoCombustibleAnio, devuelve el maximo combustible recargado en el ultimo anio.
     *
     * @throws IllegalStateException si no se han asignado datos derivados anteriormente
     * @return String con  la cantidad formateada
     */
    @Override
    public String getMaximoCombustibleAnio() {
        if(datos==null){
            throw new IllegalStateException();
        }else {
            DecimalFormat formato = new DecimalFormat("#.##");
            formato.setRoundingMode(RoundingMode.CEILING);
            double valor= datos.getMaximoCombustibleAnualRecargado();
            return formato.format(valor).replace('.',',');
        }
    }

    /**
     * Metodo getMediaRecargasXKmCombustibleMes, devuelve la media de combustible consumido por
     * kilometro recorrido del mes.
     *
     * @throws IllegalStateException si no se han asignado datos derivados anteriormente
     * @return String con la cantidad formateada
     */
    @Override
    public String getMediaRecargasXKmCombustibleMes() {
        if(datos==null){
            throw new IllegalStateException();
        }else {
            double valor = datos.getMediaCombustibleXKmMensual();
            DecimalFormat formato = new DecimalFormat("#.##");
            formato.setRoundingMode(RoundingMode.CEILING);
            return formato.format(valor).replace('.',',');
        }

    }

    /**
     * Metodo getMediaRecargasXKmCombustibleAnio, devuelve la media de combustible consumido por kilometro
     * recorrido en el anio.
     *
     * @throws IllegalStateException si no se han asignado datos derivados anteriormente
     * @return String con la cantidad formateada
     */
    @Override
    public String getMediaRecargasXKmCombustibleAnio() {
        if(datos==null){
            throw new IllegalStateException();
        }else {
            double valor = datos.getMediaCombustibleXKmAnual();
            DecimalFormat formato = new DecimalFormat("#.##");
            formato.setRoundingMode(RoundingMode.CEILING);
            return formato.format(valor).replace('.',',');
        }
    }

    /**
     * Metodo getMinimoRecargasXKmCombustibleMes, devuelve el minimo de combustible consumido por kilometro
     * recorrido en el mes.
     *
     * @throws IllegalStateException si no se han asignado datos derivados anteriormente
     * @return String con la cantidad formateada
     */
    @Override
    public String getMinimoRecargasXKmCombustibleMes() {
        if(datos==null){
            throw new IllegalStateException();
        }else {
            double valor = datos.getMinimoCombustibleXKmMensual();
            DecimalFormat formato = new DecimalFormat("#.##");
            formato.setRoundingMode(RoundingMode.CEILING);
            return formato.format(valor).replace('.',',');
        }
    }

    /**
      * Metodo getMaximoRecargasXKmCombustibleMes, devuelve el maximo de combustible consumido por kilometro
      * recorrido en el mes.
      *
      * @throws IllegalStateException si no se han asignado datos derivados anteriormente
      * @return String con la cantidad formateada
     */
    @Override
    public String getMaximoRecargasXKmCombustibleMes() {
        if(datos==null){
            throw new IllegalStateException();
        }else {
            double valor = datos.getMaximoCombustibleXKmMensual();
            DecimalFormat formato = new DecimalFormat("#.##");
            formato.setRoundingMode(RoundingMode.CEILING);
            return formato.format(valor).replace('.',',');
        }
    }

    /**
     * Metodo getMinimoRecargasXKmCombustibleAnio, devuelve el minimo de combustible consumido por kilometro
     * recorrido en el anio.
     *
     * @throws IllegalStateException si no se han asignado datos derivados anteriormente
     * @return String con la cantidad formateada
     */
    @Override
    public String getMinimoRecargasXKmCombustibleAnio() {
        if(datos==null){
            throw new IllegalStateException();
        }else {
            double valor = datos.getMinimoCombustibleXKmAnual();
            DecimalFormat formato = new DecimalFormat("#.##");
            formato.setRoundingMode(RoundingMode.CEILING);
            return formato.format(valor).replace('.',',');
        }
    }

    /**
     * Metodo getMaximoRecargasXKmCombustibleAnio, devuelve el minimo de combustible consumido por kilometro
     * recorrido en el anio.
     *
     * @throws IllegalStateException si no se han asignado datos derivados anteriormente
     * @return String con la cantidad formateada
     */
    @Override
    public String getMaximoRecargasXKmCombustibleAnio() {
        if(datos==null){
            throw new IllegalStateException();
        }else {
            double valor = datos.getMaximoCombustibleXKmAnual();
            DecimalFormat formato = new DecimalFormat("#.##");
            formato.setRoundingMode(RoundingMode.CEILING);
            return formato.format(valor).replace('.',',');
        }
    }

    /**
     * Metodo setDatosDerivadosCombustible, establece el conjunto de datos derivados asociados al consumo
     * de combustible.
     *
     * @param dtoDatosDerivadosCombustible DTODatosDerivadosCombustible
     */
    @Override
    public void setDatosDerivadosCombustible(DTODatosDerivadosCombustible dtoDatosDerivadosCombustible) {

            this.datos = dtoDatosDerivadosCombustible;

    }

    /**
     * Metodo getDatos, devuelve el conjunto de datos derivados asociados a este formateador.
     *
     * @return DTODatosDerivadosCombustible
     */
    @Override
    public DTODatosDerivadosCombustible getDatos() {
        return datos;
    }
}
